==> xfact-0.2.44.tar.gz: xfact-0.2.44/src/xfact/config/args.py <==
from dataclasses import field, dataclass
from typing import Optional


@dataclass
class ModelArguments:
    """
    Arguments pertaining to which model/config/tokenizer we are going to fine-tune from.
    """
    model_name_or_path: str = field(
        metadata={"help": "Path to pretrained model or model identifier from huggingface.co/models"}
    )
    predict_single:Optional[bool] = field(
        default=False,
        metadata={"help": "Limit decoder to signel output"}
    )
    prefix_path : Optional[str] = field(
        metadata={"help": "Path to TRIE file"},
        default="wikipedia-titles-structured-pt.pkl"
    )
    config_name: Optional[str] = field(
        default=None, metadata={"help": "Pretrained config name or path if not the same as model_name"}
    )
    tokenizer_name: Optional[str] = field(
        default=None, metadata={"help": "Pretrained tokenizer name or path if not the same as model_name"}
    )
    cache_dir: Optional[str] = field(
        default=None,
        metadata={"help": "Path to directory to store the pretrained models downloaded from huggingface.co"},
    )
    model_revision: str = field(
        default="main",
        metadata={"help": "The specific model version to use (can be a branch name, tag name or commit id)."},
    )
    use_auth_token: bool = field(
        default=False,
        metadata={
            "help": "Will use the token generated when running `transformers-cli login` (necessary to use this script "
            "with private models)."
        },
    )
    dropout_rate: float = field(
        default=None,
        metadata={
            "help": "Overwrite dropout rate for model training"
        }
    )


@dataclass
class DataTrainingArguments:
    """
    Arguments pertaining to what data we are going to input our model for training and eval.
    """

    dataset: str = field(
        metadata={"help": "Dataset dataset"}
    )
    validation_dataset: Optional[str] = field(
        default=None,
        metadata={"help": "Dataset dataset for validation set"}
    )
    reader: Optional[str] = field(
        default="base",
        metadata={"help": "Dataset dataset"}
    )
    validation_reader: Optional[str] = field(
        default=None,
        metadata={"help": "Dataset dataset"}
    )
    post_processor: Optional[str] = field(
        default="default",
        metadata={"help": "Dataset dataset"}
    )
    scorer: Optional[str] = field(
        default="classification",
        metadata={"help": "Dataset dataset"}
    )
    experiment_key: Optional[str] = field(
        default=None,
        metadata={"help": "Experiment key"}
    )
    out_file: Optional[str] = field(default=None, metadata={"help":"Save predictions to this file"})
    workspace: Optional[str] = field(
        default=None,
        metadata={"help": "Experiment workspace"}
    )
    comet_key: Optional[str] = field(
        default=None,
        metadata={"help": "Experiment Key for Comet"}
    )
    project_name: Optional[str] = field(
        default=None,
        metadata={"help": "Experiment project"}
    )
    train_file: Optional[str] = field(default=None, metadata={"help": "The input training data file (a text file)."})
    validation_file: Optional[str] = field(
        default=None,
        metadata={"help": "An optional input evaluation data file to evaluate the perplexity on (a text file)."},
    )
    test_file: Optional[str] = field(
        default=None,
        metadata={"help": "An optional input test data file to evaluate the perplexity on (a text file)."},
    )
    overwrite_cache: bool = field(
        default=False, metadata={"help": "Overwrite the cached training and evaluation sets"}
    )
    preprocessing_num_workers: Optional[int] = field(
        default=None,
        metadata={"help": "The number of processes to use for the preprocessing."},
    )
    max_seq_length: int = field(
        default=128,
        metadata={
            "help": "The maximum total input sequence length after tokenization. Sequences longer "
            "than this will be truncated, sequences shorter will be padded."
        },
    )
    pad_to_max_length: bool = field(
        default=True,
        metadata={
            "help": "Whether to pad all samples to `max_seq_length`. "
            "If False, will pad the samples dynamically when batching to the maximum length in the batch (which can "
            "be faster on GPU but will be slower on TPU)."
        },
    )
    max_train_samples: Optional[int] = field(
        default=None,
        metadata={
            "help": "For debugging purposes or quicker training, truncate the number of training examples to this "
            "value if set."
        },
    )
    max_eval_samples: Optional[int] = field(
        default=None,
        metadata={
            "help": "For debugging purposes or quicker training, truncate the number of evaluation examples to this "
            "value if set."
        },
    )
    max_predict_samples: Optional[int] = field(
        default=None,
        metadata={
            "help": "For debugging purposes or quicker training, truncate the number of prediction examples to this "
            "value if set."
        },
    )
    version_2_with_negative: bool = field(
        default=False, metadata={"help": "If true, some of the examples do not have an answer."}
    )
    null_score_diff_threshold: float = field(
        default=0.0,
        metadata={
            "help": "The threshold used to select the null answer: if the best answer has a score that is less than "
            "the score of the null answer minus this threshold, the null answer is selected for this example. "
            "Only useful when `version_2_with_negative=True`."
        },
    )
    doc_stride: int = field(
        default=128,
        metadata={"help": "When splitting up a long document into chunks, how much stride to take between chunks."},
    )
    n_best_size: int = field(
        default=20,
        metadata={"help": "The total number of n-best predictions to generate when looking for an answer."},
    )
    max_target_length: int = field(
        default=30,
        metadata={
            "help": "The maximum length of an answer that can be generated. This is needed because the start "
            "and end predictions are not conditioned on one another."
        },
    )
    train_beam: int = field(
        default=1
    )
    eval_beam: int = field(
        default=10
    )
    ignore_pad_token_for_loss: bool = field(
        default=True,
        metadata={
            "help": "Whether to ignore the tokens corresponding to padded labels in the loss computation or not."
        },
    )
    package: Optional[str] = field(
        default=None,
        metadata={"help": "Package to import"}
    )


    def __post_init__(self):
        if (self.train_file is None
            and self.validation_file is None
            and self.test_file is None
        ):
            raise ValueError("Need either a dataset name or a training/validation file/test_file.")
        else:
            if self.train_file is not None:
                extension = self.train_file.split(".")[-1]
            if self.validation_file is not None:
                extension = self.validation_file.split(".")[-1]
            if self.test_file is not None:
                extension = self.test_file.split(".")[-1]

==> xfact-0.3.50.tar.gz: xfact-0.3.50/src/xfact/config/args.py <==
from dataclasses import field, dataclass
from typing import Optional


@dataclass
class ModelArguments:
    """
    Arguments pertaining to which model/config/tokenizer we are going to fine-tune from.
    """
    model_name_or_path: str = field(
        metadata={"help": "Path to pretrained model or model identifier from huggingface.co/models"}
    )

    model_factory: Optional[str] = field(
        default="huggingface",
        metadata={"help": "model factory to use"}
    )
    predict_single:Optional[bool] = field(
        default=False,
        metadata={"help": "Limit decoder to single output"}
    )
    prefix_path : Optional[str] = field(
        metadata={"help": "Path to TRIE file"},
        default="wikipedia-titles-structured-pt.pkl"
    )
    config_name: Optional[str] = field(
        default=None, metadata={"help": "Pretrained config name or path if not the same as model_name"}
    )
    tokenizer_name: Optional[str] = field(
        default=None, metadata={"help": "Pretrained tokenizer name or path if not the same as model_name"}
    )
    cache_dir: Optional[str] = field(
        default=None,
        metadata={"help": "Path to directory to store the pretrained models downloaded from huggingface.co"},
    )
    model_revision: str = field(
        default="main",
        metadata={"help": "The specific model version to use (can be a branch name, tag name or commit id)."},
    )
    use_auth_token: bool = field(
        default=False,
        metadata={
            "help": "Will use the token generated when running `transformers-cli login` (necessary to use this script "
            "with private models)."
        },
    )
    dropout_rate: float = field(
        default=None,
        metadata={
            "help": "Overwrite dropout rate for model training"
        }
    )


@dataclass
class DataTrainingArguments:
    """
    Arguments pertaining to what data we are going to input our model for training and eval.
    """

    dataset: str = field(
        metadata={"help": "Dataset dataset"}
    )
    validation_dataset: Optional[str] = field(
        default=None,
        metadata={"help": "Dataset dataset for validation set"}
    )
    reader: Optional[str] = field(
        default="base",
        metadata={"help": "Dataset dataset"}
    )
    validation_reader: Optional[str] = field(
        default=None,
        metadata={"help": "Dataset dataset"}
    )
    post_processor: Optional[str] = field(
        default="default",
        metadata={"help": "Dataset dataset"}
    )
    weighted_loss: Optional[bool] = field(
        default=True,
        metadata={"help": "Weighted loss function for classes"}
    )
    scorer: Optional[str] = field(
        default="classification",
        metadata={"help": "Dataset dataset"}
    )
    experiment_key: Optional[str] = field(
        default=None,
        metadata={"help": "Experiment key"}
    )
    out_file: Optional[str] = field(default=None, metadata={"help":"Save predictions to this file"})
    workspace: Optional[str] = field(
        default=None,
        metadata={"help": "Experiment workspace"}
    )
    comet_key: Optional[str] = field(
        default=None,
        metadata={"help": "Experiment Key for Comet"}
    )
    project_name: Optional[str] = field(
        default=None,
        metadata={"help": "Experiment project"}
    )
    train_file: Optional[str] = field(default=None, metadata={"help": "The input training data file (a text file)."})
    validation_file: Optional[str] = field(
        default=None,
        metadata={"help": "An optional input evaluation data file to evaluate the perplexity on (a text file)."},
    )
    test_file: Optional[str] = field(
        default=None,
        metadata={"help": "An optional input test data file to evaluate the perplexity on (a text file)."},
    )
    overwrite_cache: bool = field(
        default=False, metadata={"help": "Overwrite the cached training and evaluation sets"}
    )
    preprocessing_num_workers: Optional[int] = field(
        default=None,
        metadata={"help": "The number of processes to use for the preprocessing."},
    )
    max_seq_length: int = field(
        default=128,
        metadata={
            "help": "The maximum total input sequence length after tokenization. Sequences longer "
            "than this will be truncated, sequences shorter will be padded."
        },
    )
    pad_to_max_length: bool = field(
        default=True,
        metadata={
            "help": "Whether to pad all samples to `max_seq_length`. "
            "If False, will pad the samples dynamically when batching to the maximum length in the batch (which can "
            "be faster on GPU but will be slower on TPU)."
        },
    )
    max_train_samples: Optional[int] = field(
        default=None,
        metadata={
            "help": "For debugging purposes or quicker training, truncate the number of training examples to this "
            "value if set."
        },
    )
    max_eval_samples: Optional[int] = field(
        default=None,
        metadata={
            "help": "For debugging purposes or quicker training, truncate the number of evaluation examples to this "
            "value if set."
        },
    )
    max_predict_samples: Optional[int] = field(
        default=None,
        metadata={
            "help": "For debugging purposes or quicker training, truncate the number of prediction examples to this "
            "value if set."
        },
    )
    version_2_with_negative: bool = field(
        default=False, metadata={"help": "If true, some of the examples do not have an answer."}
    )
    null_score_diff_threshold: float = field(
        default=0.0,
        metadata={
            "help": "The threshold used to select the null answer: if the best answer has a score that is less than "
            "the score of the null answer minus this threshold, the null answer is selected for this example. "
            "Only useful when `version_2_with_negative=True`."
        },
    )
    doc_stride: int = field(
        default=128,
        metadata={"help": "When splitting up a long document into chunks, how much stride to take between chunks."},
    )
    n_best_size: int = field(
        default=20,
        metadata={"help": "The total number of n-best predictions to generate when looking for an answer."},
    )
    max_target_length: int = field(
        default=30,
        metadata={
            "help": "The maximum length of an answer that can be generated. This is needed because the start "
            "and end predictions are not conditioned on one another."
        },
    )
    train_beam: int = field(
        default=1
    )
    eval_beam: int = field(
        default=10
    )
    ignore_pad_token_for_loss: bool = field(
        default=True,
        metadata={
            "help": "Whether to ignore the tokens corresponding to padded labels in the loss computation or not."
        },
    )
    package: Optional[str] = field(
        default=None,
        metadata={"help": "Package to import"}
    )


    def __post_init__(self):
        if (self.train_file is None
            and self.validation_file is None
            and self.test_file is None
        ):
            raise ValueError("Need either a dataset name or a training/validation file/test_file.")
        else:
            if self.train_file is not None:
                extension = self.train_file.split(".")[-1]
            if self.validation_file is not None:
                extension = self.validation_file.split(".")[-1]
            if self.test_file is not None:
                extension = self.test_file.split(".")[-1]
